Linux Sound subsystem development
 help / color / mirror / Atom feed
From: "Pål-Kristian Engstad" <engstad@worldnet.att.net>
To: linux-sound@vger.kernel.org
Subject: Patch for Creative SB AWE64 Gold ISAPnP card.
Date: Fri, 26 May 2000 04:27:19 +0000	[thread overview]
Message-ID: <marc-linux-sound-95931685010223@msgid-missing> (raw)

The following patch worked like a charm for me.
No more need for isapnp tools!

PKE.

--- sb_card.c.orig Thu May 25 09:15:18 2000
+++ sb_card.c   Thu May 25 21:22:17 2000
@@ -40,7 +40,9 @@
  *  Thanks to Gaël Quéri and Alessandro Zummo for testing and fixes.
  *  Paul E. Laufer <pelaufer@csupomona.edu>
  *
  * 06-05-2000 added another card. Daniel M. Newman <dmnewman@pobox.com>
  *
  */
 
@@ -452,6 +454,11 @@
        ISAPNP_VENDOR('@','X','@'), ISAPNP_FUNCTION(0x2001),
        ISAPNP_VENDOR('@','H','@'), ISAPNP_FUNCTION(0x0001),
        1,0,0,0},
+   {"Creative SB AWE64 Gold",
+           ISAPNP_VENDOR('C','T','L'), ISAPNP_DEVICE(0x00B2),
+           ISAPNP_VENDOR('C','T','L'), ISAPNP_FUNCTION(0x0044),
+           0,0,0,0,
+           0,1,1,-1},
    {0}
 };
                       
@@ -40,7 +40,9 @@
  *  Paul E. Laufer <pelaufer@csupomona.edu>
  *
- * 06-05-2000 added another card. Daniel M. Newman <dmnewman@pobox.com>
+ * 06-05-2000 Added another card. Daniel M. Newman <dmnewman@pobox.com>
+ *
+ * 25-05-2000 Added Creative SB AWE64 Gold. Pål-Kristian Engstad <engstad@att.net>
  *
  */

                 reply	other threads:[~2000-05-26  4:27 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=marc-linux-sound-95931685010223@msgid-missing \
    --to=engstad@worldnet.att.net \
    --cc=linux-sound@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox